@@ -12,13 +12,8 @@ Usage::
     session_client: ComprehendMedicalClient = session.client("comprehendmedical")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
-from typing import Any, Dict
+from typing import Any, Dict, TYPE_CHECKING
 from botocore.exceptions import ClientError as Boto3ClientError
-
-# pylint: disable=import-self
-import mypy_boto3_comprehendmedical.client as client_scope
 from mypy_boto3_comprehendmedical.type_defs import (
     ClientDescribeEntitiesDetectionV2JobResponseTypeDef,
     ClientDescribePhiDetectionJobResponseTypeDef,
@@ -45,45 +40,57 @@ from mypy_boto3_comprehendmedical.type_defs import (
 __all__ = ("ComprehendMedicalClient",)
 
 
+class Exceptions:
+    ClientError: Boto3ClientError
+    InternalServerException: Boto3ClientError
+    InvalidEncodingException: Boto3ClientError
+    InvalidRequestException: Boto3ClientError
+    ResourceNotFoundException: Boto3ClientError
+    ServiceUnavailableException: Boto3ClientError
+    TextSizeLimitExceededException: Boto3ClientError
+    TooManyRequestsException: Boto3ClientError
+    ValidationException: Boto3ClientError
+
+
 class ComprehendMedicalClient:
     """
-    [ComprehendMedical.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client)
+    [ComprehendMedical.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client)
     """
 
-    exceptions: client_scope.Exceptions
+    exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
         """
 
     def describe_entities_detection_v2_job(
         self, JobId: str
     ) -> ClientDescribeEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.describe_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
+        [Client.describe_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
         """
 
     def describe_phi_detection_job(
         self, JobId: str
     ) -> ClientDescribePhiDetectionJobResponseTypeDef:
         """
-        [Client.describe_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
+        [Client.describe_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
         """
 
     def detect_entities(self, Text: str) -> ClientDetectEntitiesResponseTypeDef:
         """
-        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
+        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
         """
 
     def detect_entities_v2(self, Text: str) -> ClientDetectEntitiesV2ResponseTypeDef:
         """
-        [Client.detect_entities_v2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
+        [Client.detect_entities_v2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
         """
 
     def detect_phi(self, Text: str) -> ClientDetectPhiResponseTypeDef:
         """
-        [Client.detect_phi documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
+        [Client.detect_phi documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
         """
 
     def generate_presigned_url(
@@ -94,17 +101,17 @@ class ComprehendMedicalClient:
         HttpMethod: str = None,
     ) -> None:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
         """
 
     def infer_icd10_cm(self, Text: str) -> ClientInferIcd10CmResponseTypeDef:
         """
-        [Client.infer_icd10_cm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
+        [Client.infer_icd10_cm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
         """
 
     def infer_rx_norm(self, Text: str) -> ClientInferRxNormResponseTypeDef:
         """
-        [Client.infer_rx_norm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
+        [Client.infer_rx_norm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
         """
 
     def list_entities_detection_v2_jobs(
@@ -114,7 +121,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ClientListEntitiesDetectionV2JobsResponseTypeDef:
         """
-        [Client.list_entities_detection_v2_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
+        [Client.list_entities_detection_v2_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
         """
 
     def list_phi_detection_jobs(
@@ -124,7 +131,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ClientListPhiDetectionJobsResponseTypeDef:
         """
-        [Client.list_phi_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
+        [Client.list_phi_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
         """
 
     def start_entities_detection_v2_job(
@@ -138,7 +145,7 @@ class ComprehendMedicalClient:
         KMSKey: str = None,
     ) -> ClientStartEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.start_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
+        [Client.start_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
         """
 
     def start_phi_detection_job(
@@ -152,29 +159,17 @@ class ComprehendMedicalClient:
         KMSKey: str = None,
     ) -> ClientStartPhiDetectionJobResponseTypeDef:
         """
-        [Client.start_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
+        [Client.start_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
         """
 
     def stop_entities_detection_v2_job(
         self, JobId: str
     ) -> ClientStopEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.stop_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
+        [Client.stop_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
         """
 
     def stop_phi_detection_job(self, JobId: str) -> ClientStopPhiDetectionJobResponseTypeDef:
         """
-        [Client.stop_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
+        [Client.stop_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.8/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
         """
-
-
-class Exceptions:
-    ClientError: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    InvalidEncodingException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceUnavailableException: Boto3ClientError
-    TextSizeLimitExceededException: Boto3ClientError
-    TooManyRequestsException: Boto3ClientError
-    ValidationException: Boto3ClientError
